=======
History
=======

0.2.0 (2020-09-28)
------------------

* First release on PyPI.


0.3.0 (2020-09-29
-----------------

* added papermill and bash operators

0.4.0 (2020-09-30)

* added dvc operators
* added python operators
* review language definition
* update function registry print